@@ -47,7 +47,7 @@ class TelegramBot:
             assert isinstance(bot_api, TelegramBotAPI), True
         else:
             logger.warning(
-                "Your bot api is not a TelegramBotAPI instance. A default bot api is using."
+                "Your bot API object is not a TelegramBotAPI instance. A default bot api is using."
             )
             bot_api = TelegramBotAPI()
         self._bot_api = bot_api
@@ -66,7 +66,7 @@ class TelegramBot:
                     kwargs: other kwargs of sendXXX api method
                 """
                 kwargs.update({
-                    "chat_id": message.chat.id,
+                    "chat_id": message.from_user.id,
                     "reply_to_message_id": message.message_id,
                 })
                 return getattr(self._bot_api, "send{0}".format(
@@ -169,6 +169,16 @@ class TelegramBot:
         finally:
             session.save()
 
+    def push_ui(self, user_id: int, message):
+        with self.session(user_id) as session:
+            ui_stack = session.get("ui_stack", [])
+            ui_stack.append(message)
+            session["ui_stack"] = ui_stack
+
+    def pop_ui(self, user_id: int):
+        with self.session(user_id) as session:
+            return session["ui_stack"].pop()
+
     def get_text(self, lang_code: str, text: str) -> str:
         if self._i18n_source:
             lang_source = self._i18n_source.get(lang_code, None)
